
%% setup parameters
clear;
listcheck=1; % 0=single file, 1=batch analysis provide a list if used
samplelimit=540000; % limit of data point for analysis
if listcheck==0
    filename='D:\data\xintong\190126\190126_box_2\190126_#68_novelday.txt';  
else
    listfile='D:\data\xintong\apomorphine\data2\list_apomorphine.xlsx';  % include reference coordinate in the excel file B=x, C=y
end
outputfile='D:\data\xintong\apomorphine\data2\result_apomorphine.mat'; % outputfile has to be .mat file
outputtracefolder='D:\data\xintong\apomorphine\data2\plot'; % output folder for images
reference=[0.29,0.29]; % define the reference point 0.5 means center, can define it in the file list
ROI_center=[0.2,0.8,0.2,0.8]; % 0-1 [x1,x2,y1,y2]
ROI_corner1=[0,0.15,0,0.15];
ROI_corner2=[0.85,1,0,0.15];
ROI_corner3=[0,0.15,0.85,1];
ROI_corner4=[0.85,1,0.85,1];
approachthreshold_distance=0.16; % criteria determined as appraching.
retreatthreshold_distance=0.162; % criteria determined as retreat
approachthreshold_duration=10; % minimum duration for an envent unit frames
filter=15; % number of force readout for smoothing 
bin=30000; % number of dot to accumulate for histogram
samplefrequency=100; % set the sample frequency
scale=44; % unit cm 1=x cm


%% for single file
if listcheck==0
    force=textread(filename); %#ok<DTXTRD> % readforce data
    
    if size(force,1)>samplelimit  % limit the data analyzed
        force=force(1:samplelimit,:);
    end    
    
    force_a=Forcefilter(force(:,1),filter); % filter force 
    force_b=Forcefilter(force(:,2),filter);
    force_c=Forcefilter(force(:,3),filter);
    force_d=Forcefilter(force(:,4),filter);
    
    [x,y]=Position(force_a,force_b,force_c,force_d); % calculate the absolute position 
    [distance]=Traveldistance(x,y); % calculate distance traveled timecourse    
    
    [time_center]=Timespent(ROI_center,x,y); % calculate time spent on particular positions
    [time_corner1]=Timespent(ROI_corner1,x,y);
    [time_corner2]=Timespent(ROI_corner2,x,y);
    [time_corner3]=Timespent(ROI_corner3,x,y);
    [time_corner4]=Timespent(ROI_corner4,x,y);
        
    [distance_bin]=Bindata(distance, bin);
    [time_center_bin]=Bindata(time_center,bin);
    [time_corner1_bin]=Bindata(time_corner1,bin);
    [time_corner2_bin]=Bindata(time_corner2,bin);
    [time_corner3_bin]=Bindata(time_corner3,bin);
    [time_corner4_bin]=Bindata(time_corner4,bin);
        
    time_corner_bin=time_corner1_bin + time_corner2_bin + time_corner3_bin + time_corner4_bin;
    time_other_bin=length(x) - time_center_bin - time_corner_bin; % time spent in other areas

    [distance_reference]=Distancetoreference(reference,x,y); % calculate the distance to reference area
    [approach_number, approach_time]=Approachparameter(distance_reference,approachthreshold_distance,approachthreshold_duration,retreatthreshold_distance,bin); % get the timepoint of approaching
    
    x=x*scale; % calculate the absolute value
    y=y*scale;
    distance=distance*scale;
    distance_reference=distance_reference*scale;
    distance_bin=distance_bin*scale;
    time_center_bin=time_center_bin/samplefrequency;
    time_corner_bin=time_corner_bin/samplefrequency;
    time_other_bin=time_other_bin/samplefrequency;
    approach_time=approach_time/samplefrequency;
    time_sequence=(0:length(x)-1)/samplefrequency;
    
          
    Makefigure(filename,outputtracefolder,x,y,scale,... % make figure
               time_sequence,distance_reference, bin)

    result.filename={filename};    % output data
    result.distance_bin=distance_bin;
    result.time_center=time_center_bin;
    result.time_corner=time_corner_bin;
    result.time_other=time_other_bin;
    result.approach_number=approach_number;
    result.approach_time=approach_time;
    result.x=x;
    result.y=y;
    result.distance=distance;
    result.distance_reference=distance_reference;
end
    
%% for filelist
if listcheck~=0
    [~,~,content]=xlsread(listfile); 
    filelist=char(content(:,1));    
    [missingfile]=Filecheck(filelist);
    
    if size(missingfile)>0  % check the files
        disp 'ERROR: File not found'
        missingfile
        return;
    else
        disp 'Filelist checked'
    end
    
    for i=1:size(filelist,1)
        filename=filelist(i,:);
        
        if size(content,2)==3 % change reference if defined in the list
            reference=[cell2mat(content(i,2)),cell2mat(content(i,3))];
        end       
        
        force=textread(filename); %#ok<DTXTRD> % readforce data
        
        if size(force,1)>samplelimit  % limit the data analyzed
            force=force(1:samplelimit,:);
        end   
        
        force_a=Forcefilter(force(:,1),filter); % filter force 
        force_b=Forcefilter(force(:,2),filter);
        force_c=Forcefilter(force(:,3),filter);
        force_d=Forcefilter(force(:,4),filter);

        [x,y]=Position(force_a,force_b,force_c,force_d); % calculate the absolute position 
        [distance]=Traveldistance(x,y); % calculate distance traveled timecourse
        [distance_bin]=Bindata(distance, bin);

        [time_center]=Timespent(ROI_center,x,y); % calculate time spent on particular positions
        [time_corner1]=Timespent(ROI_corner1,x,y);
        [time_corner2]=Timespent(ROI_corner2,x,y);
        [time_corner3]=Timespent(ROI_corner3,x,y);
        [time_corner4]=Timespent(ROI_corner4,x,y);

        [distance_bin]=Bindata(distance, bin);
        [time_center_bin]=Bindata(time_center,bin);
        [time_corner1_bin]=Bindata(time_corner1,bin);
        [time_corner2_bin]=Bindata(time_corner2,bin);
        [time_corner3_bin]=Bindata(time_corner3,bin);
        [time_corner4_bin]=Bindata(time_corner4,bin);

        time_corner_bin=time_corner1_bin + time_corner2_bin + time_corner3_bin + time_corner4_bin;
        time_other_bin=length(x) - time_center_bin - time_corner_bin; % time spent in other areas

        [distance_reference]=Distancetoreference(reference,x,y); % calculate the distance to reference area
        [approach_number, approach_time]=Approachparameter(distance_reference,approachthreshold_distance,approachthreshold_duration,retreatthreshold_distance,bin); % get the timepoint of approaching


        x=x*scale;
        y=y*scale;
        distance=distance*scale;
        distance_reference=distance_reference*scale;
        distance_bin=distance_bin*scale;
        time_center_bin=time_center_bin/samplefrequency;
        time_corner_bin=time_corner_bin/samplefrequency;
        time_other_bin=time_other_bin/samplefrequency;
        approach_time=approach_time/samplefrequency; 
        time_sequence=(0:length(x)-1)/samplefrequency;
       
        Makefigure(filename,outputtracefolder,x,y,scale,... % make figure
               time_sequence,distance_reference, bin)
          
        result.filename(1,i)={filename};     
        result.distance_bin(:,i)=distance_bin;
        result.time_center(:,i)=time_center_bin;
        result.time_corner(:,i)=time_corner_bin;
        result.time_other(:,i)=time_other_bin;
        result.approach_number(:,i)=approach_number;
        result.approach_time(:,i)=approach_time;
        result.x(:,i)=x;
        result.y(:,i)=y;
        result.distance(:,i)=distance;
        result.distance_reference(:,i)=distance_reference;     
    end
    
    
end
    
    


%% add calculation parameters to the output file

    result.outputfile={outputfile}; % save parameters
    result.ROI_center=ROI_center;
    result.ROI_corner1=ROI_corner1;
    result.ROI_corner2=ROI_corner2;
    result.ROI_corner3=ROI_corner3;
    result.ROI_corner4=ROI_corner4;
    result.reference=reference;
    result.filter=filter;
    result.bin=bin;
    result.approachthreshold_distance=approachthreshold_distance;
    result.retreatthreshold_distance=retreatthreshold_distance;
    result.approachthreshold_duration=approachthreshold_duration;
    result.samplefrequency=samplefrequency;
    result.scale=scale;


%% save files

save(outputfile,'result');
disp 'All Done!'

